# PRD 초안 템플릿

여기에 아이디어를 자유롭게 작성하세요.
`/tm:convert-prd` 커맨드로 TaskMaster PRD 포맷으로 변환됩니다.

---

## 뭘 만들고 싶은지

(프로젝트 목적, 해결하려는 문제)



## 주요 기능

(만들고 싶은 기능들 나열)



## 기술 스택

(사용할 기술, 프레임워크 등)



## 만드는 순서

(먼저 만들 것, 나중에 만들 것)



## 기타

(걱정되는 점, 참고사항 등)


